@@ -23,7 +23,7 @@
  *   If not, see <http://www.gnu.org/licenses/>.
  */
 
-# define ISOTIME_VERSION      "isotime : V1.6 Peter Boesecke 2012-10-28"
+# define ISOTIME_VERSION      "isotime : V1.8 Peter Boesecke 2015-12-08"
 /*+++------------------------------------------------------------------------
 NAME
    isotime --- routines for isotime conversion 
@@ -42,6 +42,10 @@ HISTORY
   2012-10-27 V1.5 PB cpo: skip leading white spaces,
                      shiftepoch added
   2012-10-28 V1.6 PB isotime_mode, isotime_str2mode, isotime_mode2str
+  2015-12-07 V1.7 PB toupper, isdigit and isspace replaced with the macros
+                     TOUPPER, ISDIGIT and ISSPACE.
+  2015-12-08 V1.8 PB epoch2isotime: 
+                     fract (unused-but-set-variable) commented
 
 PUBLIC extern
        IsotimeEpoch isotime2epoch( const char * isotime_s ),
@@ -77,6 +81,12 @@ LIMITATION
 # define MIN2( x, y ) (( x ) > ( y ))?( y ):( x )
 #endif
 
+# define ISGRAPH(c) isgraph((int)(c))
+# define ISSPACE(c) isspace((int)(c))
+# define ISDIGIT(c) isdigit((int)(c))
+# define TOLOWER(s) (char)tolower((int)(s))
+# define TOUPPER(s) (char)toupper((int)(s))
+
 /******************************************************************************
 * Private Constants                                                           *
 ******************************************************************************/
@@ -129,15 +139,15 @@ char *trim( char buffer[], size_t buflen, const char * s )
   if ( s ) {
     pstart = s;
 
-    while (isspace(*pstart)) pstart++;  // skip leading white spaces
-    for (i = strlen (s) -1; i>=0 && isspace(s[i]); i--);
+    while (ISSPACE(*pstart)) pstart++;  // skip leading white spaces
+    for (i = strlen (s) -1; i>=0 && ISSPACE(s[i]); i--);
     pend = &s[i+1];                 // end position
 
     slen = pend-pstart;
     slen = MIN2(slen,buflen-1);
 
     ps = pstart;
-    for ( i=0;i<slen;i++ ) buffer[i] = toupper( *ps++ ); // uppercase copy
+    for ( i=0;i<slen;i++ ) buffer[i] = TOUPPER( *ps++ ); // uppercase copy
   }
   buffer[slen]='\0'; // terminate
 
@@ -162,7 +172,7 @@ char * cpd( char buffer[], size_t buflen, char * s )
   if ( s ) {
     // copy year (4 digits)
     for (i=0;(i<4)&&(*ps)&&(cnt>0);i++) {
-      if (isdigit(*ps)) {
+      if (ISDIGIT(*ps)) {
         *pb=*ps;
         pb++;ps++;cnt--;
       } else break;
@@ -170,10 +180,10 @@ char * cpd( char buffer[], size_t buflen, char * s )
     if (i!=4) goto cpderr;
 
     // skip separator
-    if (!isdigit(*ps)) { if (*ps=='-') ps++; else goto cpderr; }
+    if (!ISDIGIT(*ps)) { if (*ps=='-') ps++; else goto cpderr; }
     // copy month (2 digits)
     for (i=0;(i<2)&&(*ps)&&(cnt>0);i++) {
-      if (isdigit(*ps)) {
+      if (ISDIGIT(*ps)) {
         *pb=*ps;
         pb++;ps++;cnt--;
       } else break;
@@ -181,10 +191,10 @@ char * cpd( char buffer[], size_t buflen, char * s )
     if (i!=2) goto cpderr;
 
     // skip separator
-    if (!isdigit(*ps)) { if (*ps=='-') ps++; else goto cpderr; }
+    if (!ISDIGIT(*ps)) { if (*ps=='-') ps++; else goto cpderr; }
     // copy day (2 digits)
     for (i=0;(i<2)&&(*ps)&&(cnt>0);i++) {
-      if (isdigit(*ps)) {
+      if (ISDIGIT(*ps)) {
         *pb=*ps;
         pb++;ps++;cnt--;
       } else break;
@@ -217,13 +227,13 @@ char * cpt( char buffer[], size_t buflen, char * s )
 
   if ( s ) {
     // skip start character 'T' or white space
-    if (!isdigit(*ps)) {
+    if (!ISDIGIT(*ps)) {
       if ((*ps=='T')||(*ps==' ')) ps++; else goto cpterr;
     }
 
     // copy hour (2 digits)
     for (i=0;(i<2)&&(*ps)&&(cnt>0);i++) {
-      if (isdigit(*ps)) {
+      if (ISDIGIT(*ps)) {
         *pb=*ps;
         pb++;ps++;cnt--;
       } else break;
@@ -231,10 +241,10 @@ char * cpt( char buffer[], size_t buflen, char * s )
     if (i!=2) goto cpterr;
 
     // skip separator
-    if (!isdigit(*ps)) { if (*ps==':') ps++; else goto cpterr; }
+    if (!ISDIGIT(*ps)) { if (*ps==':') ps++; else goto cpterr; }
     // copy minute (2 digits)
     for (i=0;(i<2)&&(*ps)&&(cnt>0);i++) {
-      if (isdigit(*ps)) {
+      if (ISDIGIT(*ps)) {
         *pb=*ps;
         pb++;ps++;cnt--;
       } else break;
@@ -242,10 +252,10 @@ char * cpt( char buffer[], size_t buflen, char * s )
     if (i!=2) goto cpterr;
 
     // skip separator
-    if (!isdigit(*ps)) { if (*ps==':') ps++; else goto cpterr; }
+    if (!ISDIGIT(*ps)) { if (*ps==':') ps++; else goto cpterr; }
     // copy second (2 digits)
     for (i=0;(i<2)&&(*ps)&&(cnt>0);i++) {
-      if (isdigit(*ps)) {
+      if (ISDIGIT(*ps)) {
         *pb=*ps;
         pb++;ps++;cnt--;
       } else break;
@@ -289,7 +299,7 @@ char * cpf( char buffer[], size_t buflen, char * s )
 
     // copy fraction (undetermined length)
     for (i=0;(*ps)&&(cnt>0);i++) {
-      if (isdigit(*ps)) {
+      if (ISDIGIT(*ps)) {
         *pb=*ps;
         pb++;ps++;cnt--;
       } else break;
@@ -297,7 +307,7 @@ char * cpf( char buffer[], size_t buflen, char * s )
 
     // skip the rest
     for (;(*ps);) {
-      if (isdigit(*ps)) {
+      if (ISDIGIT(*ps)) {
         ps++;
       } else break;
     }
@@ -330,7 +340,7 @@ char * cps( char buffer[], size_t buflen, char * s )
 
   if ( s ) {
     // check start character '-' or '+'
-    if ((*ps!='-')&&(*ps!='+')&&(!isdigit(*ps))) goto cpserr;
+    if ((*ps!='-')&&(*ps!='+')&&(!ISDIGIT(*ps))) goto cpserr;
 
     // copy start character (1 character)
     if ( (*ps)&&(cnt>0) ) {
@@ -340,14 +350,14 @@ char * cps( char buffer[], size_t buflen, char * s )
 
     // copy seconds (undetermined length)
     for (i=0;(*ps)&&(cnt>0);i++) {
-      if (isdigit(*ps)) {
+      if (ISDIGIT(*ps)) {
         *pb=*ps;
         pb++;ps++;cnt--;
       } else break;
     }
 
     // check that all digits are read
-    if (isdigit(*ps)&&(strlen(ps))) goto cpserr;
+    if (ISDIGIT(*ps)&&(strlen(ps))) goto cpserr;
 
     *pb='\0';
   }
@@ -379,7 +389,7 @@ char * cpo( char buffer[], size_t buflen, char * s )
   if ( s ) {
 
     // skip leading white spaces
-    while (isspace(*ps)) ps++;
+    while (ISSPACE(*ps)) ps++;
 
     // check start character '-' or '+'
     if ((*ps!='-')&&(*ps!='+')&&(*ps!='Z')) goto cpoerr;
@@ -396,7 +406,7 @@ char * cpo( char buffer[], size_t buflen, char * s )
     } else {
       // copy hour (2 digits)
       for (i=0;(i<2)&&(*ps)&&(cnt>0);i++) {
-        if (isdigit(*ps)) {
+        if (ISDIGIT(*ps)) {
           *pb=*ps;
           pb++;ps++;cnt--;
         } else break;
@@ -405,11 +415,11 @@ char * cpo( char buffer[], size_t buflen, char * s )
   
       if (!stop) {
         // skip separator
-        if (!isdigit(*ps)) { if (*ps==':') ps++; else stop=1; }
-        if (isdigit(*ps)&&!stop) { // read only 2 character if *ps is a digit
+        if (!ISDIGIT(*ps)) { if (*ps==':') ps++; else stop=1; }
+        if (ISDIGIT(*ps)&&!stop) { // read only 2 character if *ps is a digit
           // copy minute (2 digits)
           for (i=0;(i<2)&&(*ps)&&(cnt>0);i++) {
-            if (isdigit(*ps)) {
+            if (ISDIGIT(*ps)) {
               *pb=*ps;
               pb++;ps++;cnt--;
             } else break;
@@ -420,11 +430,11 @@ char * cpo( char buffer[], size_t buflen, char * s )
   
       if (!stop) {
         // skip separator
-        if (!isdigit(*ps)) { if (*ps==':') ps++; else stop=1; }
-        if (isdigit(*ps)&&!stop) { // read only 2 character if *ps is a digit
+        if (!ISDIGIT(*ps)) { if (*ps==':') ps++; else stop=1; }
+        if (ISDIGIT(*ps)&&!stop) { // read only 2 character if *ps is a digit
           // copy second (2 digits)
           for (i=0;(i<2)&&(*ps)&&(cnt>0);i++) {
-            if (isdigit(*ps)) {
+            if (ISDIGIT(*ps)) {
               *pb=*ps;
               pb++;ps++;cnt--;
             } else break;
@@ -921,7 +931,7 @@ const char * epoch2isotime( char buffer[], size_t buflen, IsotimeEpoch epoch )
   char osign_c;
   long year=0, month=0, day=0;
   long hh=0, mm=0, ss=0;
-  double fract=0.0;
+  // double fract=0.0; // unused-but-set-variable
   long Hh=0, Mm=0, Ss=0;
 
   long days, yd, ts, tz, leap;
@@ -945,7 +955,7 @@ const char * epoch2isotime( char buffer[], size_t buflen, IsotimeEpoch epoch )
     epoch.sec   += base;
 
     // convert2time
-    fract = epoch.fract;
+    // fract = epoch.fract; // unused-but-set-variable
 
     if (epoch.offset<0) osign_c='-'; else osign_c='+';
     tz    = epoch.offset; 
