@@ -49,9 +49,13 @@ HISTORY
                      Documentation corrected in raster_order_normalization 
                      and raster_normalization: data_dim[] must contain the 
                      output array dimensions.
+  2014-02-13 V1.6 PB raster_order_dimension added
+  2015-12-07 V1.7 PB isgraph -> ISGRAPH
+  2015-12-08 V1.8 PB raster_order2str:
+                     size_t psiz (unused-but-set-variable) commented
 
 --------------------------------------------------------------------------*/
-# define RASTER_VERSION "raster : V1.5 Peter Boesecke 2011-12-14"
+# define RASTER_VERSION "raster : V1.8 Peter Boesecke 2015-12-08"
 /****************************************************************************
 *  Include                                                                  *
 ****************************************************************************/
@@ -73,6 +77,12 @@ HISTORY
 *  PRIVATE part                                                             *
 ****************************************************************************/
 
+# define ISGRAPH(c) isgraph((int)(c))
+# define ISSPACE(c) isspace((int)(c))
+# define ISDIGIT(c) isdigit((int)(c))
+# define TOLOWER(s) (char)tolower((int)(s))
+# define TOUPPER(s) (char)toupper((int)(s))
+
 /****************************************************************************
 * Static Variables                                                          *
 ****************************************************************************/
@@ -457,6 +467,123 @@ long raster_order2number ( const long order[] )
  
 } /* raster_order2number */
 
+/*+++--------------------------------------------------------------------------
+NAME
+
+  raster_order_dimension --- conversion of input to output dimension
+
+SYNOPSIS
+
+  long * raster_order_dimension ( long * buffer, size_t nelem,
+                                  const long src_dim[],
+                                  const long src_order[], int *perrval );
+
+ARGUMENTS
+  void * buffer                output dimension buffer
+                               It must have at least the size of src_dim[].
+                               Both arrays can overlap.
+                               If buffer is NULL an output buffer with
+                               size src_dim[0]+1 is allocated and nelem
+                               is ignored.
+  size_t nelem                 elements of buffer, usually rank+1
+  const long src_dim[]         dimension array of source
+  const long src_order[]       index order of source
+
+  Index 0 of src_dim[], src_order[]  and dest_dim[] contains the rank.
+
+DESCRIPTION
+  
+  Reorders the dimension array according to the index order array. The output
+  array can be used as input in raster_order_normalization.
+
+RETURN VALUE
+
+  Success : long * pointer to output dimension buffer
+  Error   : NULL and error value in *perrval
+
+AUTHOR
+  13-Feb-2014 Peter Boesecke
+
+-----------------------------------------------------------------------------*/
+long * raster_order_dimension ( long * buffer, size_t nelem, 
+                                const long src_dim[],
+                                const long src_order[], int *perrval )
+{ static const char * ROD_Error  = "ERROR: raster_order_dimension:";
+  int errval=0;
+  long * dest_dim=NULL;
+  long i, I, N = 0l;
+
+  if (RN_debug) printf(" raster_order_dimension BEGIN\n");
+
+  if (!(src_dim&&src_order)) {
+    fprintf(stderr,"%s src_dim or src_order is NULL\n",ROD_Error);
+    errval=1;
+    goto raster_order_dimension_error;
+  }
+
+  N = src_dim[0];
+
+  if (N>src_order[0]) {
+    fprintf(stderr,"%s source order array is too short (%ld<%ld)\n",
+      ROD_Error,src_order[0],N);
+    errval=2; // order index array is too short
+    goto raster_order_dimension_error;
+  }
+
+  if (!(buffer)) {
+    /* allocate array and clear it */
+    if ( !(dest_dim = (long*) calloc( (N+1), sizeof(long) )) ) {
+      fprintf(stderr,"%s buffer allocation error\n",ROD_Error);
+      errval=3;
+      goto raster_order_dimension_error;
+    }
+    buffer = dest_dim;
+    nelem = (size_t) (N+1);
+  } else {
+    if (nelem<=N) {
+      fprintf(stderr,"%s supplied buffer too small\n",ROD_Error);
+      errval=4;
+      goto raster_order_dimension_error;
+    }
+  }
+
+  // clear buffer
+  for (i=1;i<=N;i++) 
+    buffer[i] = 0l;
+  buffer[0] = N;
+
+  for (i=1;i<=N;i++) {
+    I = labs(src_order[i]);
+    if ( (0l<I) && (I<=N) ) {
+      if (buffer[I] == 0l) {
+        buffer[I] = src_dim[i];
+      } else {
+        errval=5; // already defined
+        fprintf(stderr,"%s index %ld is already defined\n",ROD_Error,I);
+        goto raster_order_dimension_error;
+      }
+    } else {
+        errval=6; // out of range
+        fprintf(stderr,"%s index %ld is out of range\n",ROD_Error,I);
+        goto raster_order_dimension_error;
+    }
+  } // for
+
+  if (perrval) *perrval = errval;
+
+  if (RN_debug) printf(" raster_order_dimension END\n");
+
+  return( buffer );
+
+raster_order_dimension_error:
+
+  if (dest_dim) free(dest_dim);
+  if (perrval) *perrval = errval;
+  if (RN_debug) printf(" raster_order_dimension END (errval=%d)\n",errval);
+  return( NULL );
+
+} /* raster_order_dimension */
+
 /*--------------------------------------------------------------------------
 NAME
 
@@ -918,8 +1045,7 @@ SYNOPSIS
                                    const long order[], size_t item, int *perrval );
 
 ARGUMENTS
-  void * dest                  output array (must be allocated), must
-                               be different from source array
+  void * dest                  output array (must be allocated). Both arrays can overlap.
   const void * src             source array
   const long data_dim[]        dimensions of output array
   const long order[]           index order of source array
@@ -1594,7 +1720,7 @@ long * raster_str2order( long * buffer, size_t nelem,
             goto raster_string2order_error;
           }
         }
-        while (isspace(*ps)) ps++; // skip trailing white space
+        while (ISSPACE(*ps)) ps++; // skip trailing white space
         if ( (*ps)&&(no_more_parameters_allowed) ) {
           errval=7; // too many parameters, but result OK 
           break;
@@ -1783,7 +1909,8 @@ char * raster_order2str( char * buffer, size_t nelem,
 
   char * value, * ps;
 
-  size_t valsiz, psiz, siz=0l;
+  size_t valsiz, siz=0l;
+  // size_t psiz; // unused-but-set-variable
   long N, log10, n;
 
   // calculate needed string length
@@ -1818,12 +1945,12 @@ char * raster_order2str( char * buffer, size_t nelem,
 
   value[0]='\0';
   ps=value;
-  psiz=valsiz;
+  // psiz=valsiz; //unused-but-set-variable
   for (i=1;i<=order[0];i++) {
     if (i==1) snprintf(ps,valsiz,"%ld",order[i]);
     else snprintf(ps,valsiz,",%ld",order[i]);
     ps=value+strlen(value);
-    psiz=valsiz-strlen(value);
+    // psiz=valsiz-strlen(value); // unused-but-set-variable
   }
 
   if (perrval) *perrval=errval;
