@@ -22,7 +22,7 @@
  *   and the GNU Lesser General Public License  along with this program.
  *   If not, see <http://www.gnu.org/licenses/>.
  */
-# define STRLIB_VERSION    "strlib : V1.06 Peter Boesecke 2012-08-02"
+# define STRLIB_VERSION    "strlib : V1.08 Peter Boesecke 2015-12-06"
 /*---------------------------------------------------------------------------
 NAME
 
@@ -43,6 +43,9 @@ HISTORY
    2011-10-22 V1.04 PB strlib_tok and strlib_tok_r added
    2011-12-12 V1.05 PB strlib_concat corrected for buffer==a
    2012-08-02 V1.06 PB strlib_nconcat, strlib_spn added
+   2014-05-29 V1.07 PB strlib_is_crlf and strlib_trimcrlf added
+   2015-12-06 V1.08 PB tolower and toupper replaced with
+                       TOLOWER and TOUPPER
     
 ---------------------------------------------------------------------------*/
 
@@ -58,6 +61,14 @@ HISTORY
 
 # include "strlib.h"
 
+/***************************************************************************
+ * Macros                                                                  *
+ ***************************************************************************/
+# define ISGRAPH(c) isgraph((int)(c))
+# define ISSPACE(c) isspace((int)(c))
+# define TOLOWER(s) (char)tolower((int)(s))
+# define TOUPPER(s) (char)toupper((int)(s))
+
 /***************************************************************************
  * Defines                                                                 *
  ***************************************************************************/
@@ -76,7 +87,8 @@ HISTORY
 * Static Variables                                                          *
 ****************************************************************************/
 
-PRIVATE char white_spaces[7] = { ' ', '\t', '\r', '\n', '\f', '\v', '\0' };
+PRIVATE char white_spaces[] = { ' ', '\t', '\r', '\n', '\f', '\v', '\0' };
+PRIVATE char crlf[] = { '\r', '\n', '\0' };
   
 /****************************************************************************
 *  Functions                                                                *
@@ -126,6 +138,31 @@ PUBLIC int strlib_is_white ( char c )
 
 } /* strlib_is_white */
 
+/*---------------------------------------------------------------------------
+NAME
+
+    strlib_is_crlf
+
+SYNOPSIS
+
+    int strlib_is_crlf ( char c );
+
+DESCRIPTION
+
+Returns 1 if c is a carriage return or line feed, 0, if not.
+
+HISTORY
+29-May-2014 Peter Boesecke
+---------------------------------------------------------------------------*/
+PUBLIC int strlib_is_crlf ( char c )
+{
+   if (!c) return(0); // no cr or lf
+   if ( strchr( crlf, (int) c ) )
+     return(1); // cr or lf
+   else return(0); // no cr nor lf 
+
+} /* strlib_is_crlf */
+
 /*---------------------------------------------------------------------------
 NAME
 
@@ -305,6 +342,53 @@ PUBLIC char * strlib_trim ( char * s )
 
 } // strlib_trim
 
+/*---------------------------------------------------------------------------
+NAME
+
+    strlib_trimcrlf --- removes leading and trailing linefeeds
+
+SYNOPSIS
+
+   char * strlib_trimcrlf ( char * s );
+
+DESCRIPTION
+
+   Removes leading and trailing carriage returns and line feed characters
+   from the input string.
+
+RETURN VALUE
+
+   Pointer to the modified input string.
+
+---------------------------------------------------------------------------*/
+PUBLIC char * strlib_trimcrlf ( char * s )
+{ char *ps1, *ps2;
+
+  if (!s) return("");
+
+  ps1=ps2=s;
+
+  // search first non-white character (nul is not a white space)
+  while ( strlib_is_crlf( *ps2 ) ) ps2++;
+
+  // copy ps2 to ps1 until end of string
+  while ( *ps2 ) {
+    *ps1++=*ps2++;
+  }
+
+  // terminate string
+  *ps1='\0';
+
+  // remove trailing white spaces
+  while ( --ps1>=s ) {
+    if ( !strlib_is_crlf(*ps1) ) break;
+    *ps1='\0';
+  }
+
+  return( s );
+
+} // strlib_trimcrlf
+
 /*---------------------------------------------------------------------------
 NAME
 
@@ -615,7 +699,7 @@ PUBLIC char * strlib_toupper ( char * s )
 
   if(s) {
     ps=s;
-    while ( *ps ) { *ps=(char)toupper(*ps); ps++; }
+    while ( *ps ) { *ps=TOUPPER(*ps); ps++; }
   }
 
   return(s);
@@ -645,7 +729,7 @@ PUBLIC char * strlib_tolower ( char * s )
 
   if (s) {
     ps=s;
-    while ( *ps ) { *ps=(char)tolower(*ps); ps++; }
+    while ( *ps ) { *ps=TOLOWER(*ps); ps++; }
   }
 
   return(s);
@@ -689,13 +773,13 @@ PUBLIC int strlib_ncasecmp(const char *s1, const char *s2, size_t n)
   s1len = strlen(s1);
   s1len = (s1len<n)?s1len:n;
   _s1 = (char *) malloc( s1len+1 );
-  for (i=0;i<s1len;i++) _s1[i]=(char)tolower(s1[i]);
+  for (i=0;i<s1len;i++) _s1[i]=TOLOWER(s1[i]);
   _s1[s1len]='\0';
 
   s2len = strlen(s2);
   s2len = (s2len<n)?s2len:n;
   _s2 = (char *) malloc( s2len+1 );
-  for (i=0;i<s2len;i++) _s2[i]=(char)tolower(s2[i]);
+  for (i=0;i<s2len;i++) _s2[i]=TOLOWER(s2[i]);
   _s2[s2len]='\0';
 
   value = strcmp(_s1,_s2);
