@@ -47,6 +47,13 @@
 * 2010-08-05 PB Rotation array addressing adapted to agree with rot3d,      *
 *               tilt3d and waxs                                             *
 * 2010-08-18 PB calculate ParDev                                            *
+* 2015-10-08 PB roca_libversion() added                                     *
+* 2015-12-08 PB fprint_vector, roca_save_step:                              *
+*               Reducing warnings in print statements when switching        *
+*               between 32-bit and 64-bit system by transforming            *
+*               size_t variables with SIZE_T to unsigned long               *
+*               before printing as %lu. %lz is not known by all             *
+*               compilers.                                                  *
 ****************************************************************************/
 
 /***************************************************************************
@@ -58,6 +65,11 @@
 * Internal                                                                 *
 ***************************************************************************/
 
+/***************************************************************************
+* Portables Print Format for size_t variable (to be printed with %lu)      *
+***************************************************************************/
+# define SIZE_T (unsigned long)
+
 # define FREE(s) if (s) { free(s); s=NULL; }
 
 static char ROCA_Usage[ROCABUFLEN];
@@ -96,6 +108,30 @@ static int ROCA_debug = 0;
 * Routines                                                                  *
 ****************************************************************************/
 
+/*+++------------------------------------------------------------------------
+NAME
+
+   roca_libversion
+
+SYNOPSIS
+
+   const char *roca_libversion ( void )
+
+DESCRIPTION
+   Returns a pointer to RVERSION, if defined, otherwise an empty string
+
+RETURN VALUE
+   Pointer to the RVERSION string or an empty string 
+-------------------------------------------------------------------------+*/
+const char *roca_libversion   ( void )
+{
+# ifdef RVERSION
+  return ( RVERSION );
+# else
+  return ( "" );
+# endif
+} /* roca_libversion */
+
 int fprint_debug( FILE *out )
 { fprintf(out,"debug      = 0x%x\n", ROCA_debug);
   fprintf(out,"verbose    = %d\n", ROCA_debug&ROCA_VERBOSE?1:0);
@@ -137,7 +173,7 @@ int fprint_vector( FILE *out, size_t ndata, double V[], const char * label )
   // show data
   fprintf(out,"%14s %14s\n","Num",label);
   for (num=0;num<ndata;num++) {
-    fprintf(out,"%14lu %14lg\n",num,V[num]);
+    fprintf(out,"%14lu %14lg\n",SIZE_T num,V[num]);
   }
   fprintf(out,"\n");
 
@@ -1758,7 +1794,7 @@ int roca_save_step( int step, size_t ndata, RO *Ordered,
   // write data
   for ( n=0; n<ndata; n++) {
     fprintf( out, "%lu\t  %lg\t  %lg\t  %lg\t  %lg\t  %lg\r\n",
-      n, angle_step[n], azimuth_step[n], Weight[n], 
+      SIZE_T n, angle_step[n], azimuth_step[n], Weight[n], 
       Angle[n], Angle[n]-angle_step[n] );
   }
 
