@@ -23,6 +23,16 @@
 * History                                                                   *
 * 2010-08-19 PB running version                                             *
 * 2011-07-21 PB minor adaptations, strlib functions used                    *
+* 2015-12-08 PB search_list, remove_list, search_element:                   *
+*               previous (unused-but-set-variable) commented                *
+*               print_lists:                                                *
+*               Reducing warnings in print statements when switching        *
+*               between 32-bit and 64-bit system by transforming            *
+*               size_t variables with SIZE_T to unsigned long               *
+*               before printing as %lu. %lz is not known by all             *
+*               compilers.                                                  *
+*               tolower and isgraph replaced with the macros                *
+*               TOLOWER and ISGRAPH.                                        *
 ****************************************************************************/
 
 /****************************************************************************
@@ -34,6 +44,12 @@
 * Private Macros                                                           *
 ***************************************************************************/
 
+# define ISGRAPH(c) isgraph((int)(c))
+# define ISSPACE(c) isspace((int)(c))
+# define ISDIGIT(c) isdigit((int)(c))
+# define TOLOWER(s) (char)tolower((int)(s))
+# define TOUPPER(s) (char)toupper((int)(s))
+
 # define STRLEN(s) (s == (char *) NULL ? 0 : strlen ( (char *) s))
 # define STRCMP(s1,s2) strcmp ( (char *) s1, (char *) s2 )
 # define STRCPY(s1,s2) strcpy ( (char *) s1, (char *) s2 )
@@ -42,6 +58,11 @@
 
 # define MAXLEN 1024
 
+/***************************************************************************
+* Portables Print Format for size_t variable (to be printed with %lu)      *
+***************************************************************************/
+# define SIZE_T (unsigned long)
+
 /***************************************************************************
 * Static Variables                                                         *
 ***************************************************************************/
@@ -140,12 +161,12 @@ int numcmp( const char * key1, const char * key2 )
    pc1 = &buf1[0]; pc2 = &buf2[0];
 
       if (key1) for (i=0;(i<MAXLEN)&&(*key1)&&(*key1!=stop1);i++) {
-        if (isgraph(*key1)) *pc1++=toupper(*key1++); else key1++;
+        if (ISGRAPH(*key1)) *pc1++=TOUPPER(*key1++); else key1++;
       }
       *pc1='\0';
 
       if (key2) for (i=0;(i<MAXLEN)&&(*key2)&&(*key2!=stop2);i++) {
-        if (isgraph(*key2)) *pc2++=toupper(*key2++); else key2++;
+        if (ISGRAPH(*key2)) *pc2++=TOUPPER(*key2++); else key2++;
       }
       *pc2='\0';
 
@@ -327,7 +348,8 @@ int insert_list( const char *Key, LList **plist )
 search_list (success:0, error:-1)
 ---------------------------------------------------------------------------*/
 int search_list( const char *Key, LList **plist )
-{ LList *list, *previous, *next;
+{ LList *list, *next;
+  // LList *previous; // unused-but-set-variable
   int notfound = -1;
 
   if (ListDebug) printf("search_list: >>%s<<\n",Key?Key:"(null)");
@@ -337,14 +359,17 @@ int search_list( const char *Key, LList **plist )
   if (plist) *plist = NULL;
   if (!Key) return(-1);
 
-  previous = (LList *) NULL;
+  // previous = (LList *) NULL; unused-but-set-variable
   list = (LList *) NULL;
   next = ListRoot;
 
   /* search insertion point (insertion before *next) */
   while (( next ) && ( notfound<0 )) {
     notfound=numcmp(next->Key,Key);
-    if (notfound<0) { previous = next; next = next->Next; }
+    if (notfound<0) { 
+      // previous = next; unused-but-set-variable
+      next = next->Next;
+    }
   } 
 
   /* found */
@@ -388,14 +413,15 @@ int delete_list( LList *list,  LList **pnext )
 remove_list (success:0, error:-1)
 ---------------------------------------------------------------------------*/
 int remove_list( const char *Key, LList **pnext )
-{ LList *next, *previous;
+{ LList *next;
+  // LList *previous; // unused-but-set-variable
   int notfound = -1;
 
   if (ListDebug) printf("remove_list: >>%s<<\n",Key?Key:"(null)");
 
   if (!ListInit) list_init( );
 
-  previous = (LList *) NULL;
+  // previous = (LList *) NULL; unused-but-set-variable
   next = ListRoot;
 
   if (pnext) *pnext = NULL;
@@ -404,7 +430,10 @@ int remove_list( const char *Key, LList **pnext )
   /* search list */
   while (( next!=(LList *) NULL ) && ( notfound<0 )) {
     notfound=numcmp(next->Key,Key);
-    if (notfound<0) { previous = next; next = next->Next; }
+    if (notfound<0) { 
+      // previous = next; unused-but-set-variable
+      next = next->Next; 
+    }
   }
 
   /* remove list next, if found */
@@ -498,7 +527,8 @@ int insert_element( LList *list, const char *Key, LElement **pelement )
 search_element (success:0, error:-1)
 ---------------------------------------------------------------------------*/
 int search_element( LList *list, const char *Key, LElement **pelement )
-{ LElement *element, *previous, *next;
+{ LElement *element, *next;
+  // LElement *previous; // unused-but-set-variable
   int notfound = -1;
 
   if (ListDebug) printf("search_element: >>%s<<\n",Key?Key:"(null)");
@@ -509,14 +539,17 @@ int search_element( LList *list, const char *Key, LElement **pelement )
   if (pelement) *pelement = NULL;
   if (!Key) return(-1);
 
-  previous = NULL;
+  // previous = NULL; unused-but-set-variable
   element = NULL;
   next = list->Elements;
 
   /* search insertion point (insertion before *next) */
   while (( next ) && ( notfound<0 )) {
     notfound=numcmp(next->Key,Key);
-    if (notfound<0) { previous = next; next = next->Next; }
+    if (notfound<0) { 
+      // previous = next; unused-but-set-variable
+      next = next->Next; 
+    }
   }
 
   /* found */
@@ -984,7 +1017,7 @@ int print_lists( FILE * out, int level, int verbose )
     if (verbose) {
       fprintf(out,"  %s\n",SeparationLine);
       fprintf(out,"  Key                = %s\n",list->Key);
-      fprintf(out,"  ElementsLen        = '%lu'\n",list->ElementsLen);
+      fprintf(out,"  ElementsLen        = '%lu'\n",SIZE_T list->ElementsLen);
       print_elements( out, list, level-1, verbose );
       fprintf(out,"  Previous Key       = ");
       if (list->Previous)
@@ -996,7 +1029,7 @@ int print_lists( FILE * out, int level, int verbose )
         else fprintf(out,"(no next list)\n");
     } else {
       fprintf(out,"  Key                = '%s'\n",list->Key);
-      fprintf(out,"  ElementsLen        = '%lu'\n",list->ElementsLen);
+      fprintf(out,"  ElementsLen        = '%lu'\n",SIZE_T list->ElementsLen);
       print_elements( out, list, level-1, verbose );
     }
     list=list->Next;
