@@ -18,7 +18,7 @@
 /*    You should have received a copy of the GNU General Public License    */
 /*    along with this program.  If not, see <http://www.gnu.org/licenses/>.*/
 /***************************************************************************/
-# define SAXSRPK_VERSION "SaxsReplacekey : V1.18 Peter Boesecke 2013-05-28"
+# define SAXSRPK_VERSION "SaxsReplacekey V1.23 Peter Boesecke 2015-12-08"
 /*+++------------------------------------------------------------------------
 NAME
    SaxsReplacekey --- Replaces keys in strings with values
@@ -33,12 +33,15 @@ INCLUDE FILES
 RESTRICTIONS
 
 DESCRIPTION
+  FNAME  file name (as given)
+  <file name> = [FPATH][FBASE][FEXT]
+  FPATH  file path (file name path, extracted from file name)
+  FBASE  base name (file name without path, without extension)
+  FEXT   extension (including separator, extracted from file name)
   FNUM   file number, e.g. value of %%%% in name%%%%.edf 
   MNUM   memory number (positiv image data, negativ variance data, default 1)
   INUM   image number
   LNUM   loop number
-  FNAME  file name
-  FPATH  file path (extracted from file name)
   CYCLES number of cycles before output image is written
 
   NCNT (ihb[isblock].DataCtrl) and ACNT (ihb[isblock].ActualLoopCount) must
@@ -73,6 +76,12 @@ HISTORY
 2010-11-08 V1.16 spkey: NUM==0 -> ihblock=isblock=1
 2010-11-18 V1.17 FPATH
 2013-05-28 V1.18 replacekey_show added
+2015-10-04 V1.19 hasreplacekey added
+2015-10-05 V1.20 spkey: special keys FBASE, FEXT, FBODY added.
+2015-10-12 V1.21 definition of FBASE and FBODY adapted
+2015-10-13 V1.22 FBODY is deprecated, but still supported
+2015-12-08 V1.23 spkey: pkend (unused-but-set-variable) commented
+
 --------------------------------------------------------------------------*/
 
 /***************************************************************************
@@ -116,12 +125,15 @@ HISTORY
      [<key>] or [<key>,<blkno>] or [<key>,<blkno>,<npar>]\n\
     Special keys (case sensitive)\n\
      Key    Description\n\
+     FNAME  file name (as given)\n\
+       <file name> = [FPATH][FBASE][FEXT]\n\
+     FPATH  file path (filename path, extracted from file name)\n\
+     FBASE  base name (file name without path, without extension)\n\
+     FEXT   extension (including separator, extracted from file name)\n\
      FNUM   file number, e.g. value of %%%% in name%%%%.edf\n\
      MNUM   memory number (positiv image data, negativ variance data, default 1)\n\
      INUM   image number\n\
      LNUM   loop number\n\
-     FNAME  file name\n\
-     FPATH  file path (extracted from file name)\n\
      CYCLES number of cycles before output image is written\
 "
 
@@ -192,6 +204,37 @@ const char * replacekey_show ( void )
 { return(SAXSRPK_SHOW);
 } // replacekey_show
 
+/*+++------------------------------------------------------------------------
+NAME
+
+    hasreplacekey
+
+SYNOPSIS
+
+    int hasreplacekey( const char * string );
+
+DESCRIPTION
+
+Returns 1 string has a key between [ and ], otherwise 0.
+
+HISTORY
+04-Oct-2015 Peter Boesecke
+---------------------------------------------------------------------------*/
+int hasreplacekey( const char * string )
+{ int found=0;
+  char *ps=NULL, *pe=NULL;
+
+  ps = strchr( string, (int) SAXSRPK_START );
+  if (ps) {
+    pe = strchr( ps, (int) SAXSRPK_END );
+  }
+
+  if (pe) found=1;
+
+  return(found);
+
+} /* hasreplacekey */
+
 /*---------------------------------------------------------------------------
 NAME
  
@@ -250,7 +293,7 @@ SYNTAX
     If (Num == NULL) Num[i]==1 is used
 
 RESTRICTIONS
-    All image blocks must be opened. Only values from opened image blocks can 
+    All image blocks must be open. Only values from open image blocks can 
     be read. Otherwise the keys are not replaced.
     If any of the pointers pcb or ib are NULL the keys are not replaced. The 
     input is copied to the output. 
@@ -408,7 +451,7 @@ char * spkey( char ** pb, const char **ps, long npar,
               long blkno, int level, int * pstatus)
 {  const char *psstart, *psstop;
    char *value;
-   char key[EdfMaxKeyLen+1], *pk, *pkend;
+   char key[EdfMaxKeyLen+1], *pk; //, *pkend; unused-but-set-variable
    char Line[EdfMaxValLen+1], *pL;
    int stream, DataChain;
    long DataNumber, StreamOpenMode;
@@ -448,7 +491,7 @@ char * spkey( char ** pb, const char **ps, long npar,
  
    value = *pb;
    pk = key;
-   pkend = key+EdfMaxKeyLen;
+   // pkend = key+EdfMaxKeyLen; unused-but-set-variable
    while ((*pk)&&(**ps))
      switch (**ps) {
        case SAXSRPK_START:
@@ -533,11 +576,20 @@ char * spkey( char ** pb, const char **ps, long npar,
    } else if ( strncmp( key,"FPATH", 5 ) == 0 ) {
      //FilePath
      filename_path ( Line, EdfMaxValLen+1, ib[isblock].FileName );
+   } else if ( strncmp( key,"FBASE", 5 ) == 0 ) {
+     //Basename (file name without path, without extension)
+     filename_base ( Line, EdfMaxValLen+1, ib[isblock].FileName );
+   } else if ( strncmp( key,"FEXT", 4 ) == 0 ) {
+     //Extension of basename
+     filename_extension ( Line, EdfMaxValLen+1, ib[isblock].FileName );
+   } else if ( strncmp( key,"FBODY", 5 ) == 0 ) {
+     //Bodyname (filename without extension)
+     filename_body ( Line, EdfMaxValLen+1, ib[isblock].FileName );
    } else if ( strncmp( key,"CYCLES", 6 ) == 0 ) {
      //Cycles
      num_long2str ( Line, EdfMaxValLen+1,pcb->Cycles,&ErrorValue);
      SetSaxsErrorExternal ( ErrorValue, ReportSaxsImageError );
-   } else { 
+   } else {
      // read header value and copy it to *pb
      stream = ib[ihblock].Stream;
      StreamOpenMode = ib[ihblock].StreamOpenMode;
@@ -546,15 +598,15 @@ char * spkey( char ** pb, const char **ps, long npar,
      DataChain = ib[ihblock].Memory.V;
 
      if ( !(( IO_DontReadWrite | IO_Dummy ) & StreamOpenMode ) ) {
-     // now search header keys
-     edf_read_header_line ( stream, DataNumber, DataChain,
-                            key, Line, &ErrorValue, &keystatus );
-     SetSaxsErrorExternal ( ErrorValue, ReportSaxsImageError );
+       // now search header keys
+       edf_read_header_line ( stream, DataNumber, DataChain,
+                              key, Line, &ErrorValue, &keystatus );
+       SetSaxsErrorExternal ( ErrorValue, ReportSaxsImageError );
      } else keystatus = KeywordMissing;
      if (pcb->TestBit>1) {
-     printf("    in spkey: key cannot be read from file (block=%ld)\n",ihblock);
-     printf("              stream=%d, DataNumber=%ld, DataChain=%d, key=%s\n",
-                           stream, DataNumber, DataChain, key);
+       printf("    in spkey: key cannot be read from file (block=%ld)\n",ihblock);
+       printf("              stream=%d, DataNumber=%ld, DataChain=%d, key=%s\n",
+                             stream, DataNumber, DataChain, key);
      }
    }
 
