@@ -89,9 +89,10 @@
                       in a region of interest (roi) with lengths (fil_1, fil_2) 
                       centered at the unset pixel. The variances
                       of these pixels will not be updated and remain VarDummy.
+  2016-04-02  PB 4.07 floor = > floorf
 
 ---*/
-# define Version  "saxs_average V4.06 2013-05-27, Peter Boesecke"
+# define Version  "saxs_average V4.07 2016-04-02, Peter Boesecke"
 
 # include <errno.h>
 # include <stdio.h>
@@ -891,7 +892,7 @@ long fill_empty_points( float *data, long dim_1, long dim_2,
     // The dummy value must be outside the range of values of the array copy.
     if ( NODUMMYDEFINED(dummy, ddummy) ) {
       // define temporary dummy and ddummy
-      dummy = (floor) ( MIN2( fminval ( copy, dim_1*dim_2 ),0.0 ) ) - 10;
+      dummy = FLOORF ( MIN2( fminval ( copy, dim_1*dim_2 ),0.0 ) ) - 10 ;
       ddummy = DDSET(dummy);
       // set all empty points in copy to dummy
       emptypoint = first_point( emptypoints );
